Pipeline
========

Pipeline is an asset packaging library for Django, providing both CSS and JavaScript concatenation and compression, built-in JavaScript template support, and optional data-URI image and font embedding.

To install it : ::

    pip install django-pipeline


For documentation, usage, and examples, see :
http://django-pipeline.readthedocs.org

To suggest a feature or report a bug :
https://github.com/cyberdelia/django-pipeline/issues
